GameController class

Inheritance

Constructors

GameController(TickerProvider tickerProvider)

Properties

astronaut Astronaut
getter/setter pair
gravity double
final
groundY double
final
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
isGameOver bool
getter/setter pair
jumpVelocity double
final
obstacleAssets List<String>
final
obstacleHeight double
final
obstacles List<Obstacle>
getter/setter pair
obstacleSpeed double
final
obstacleWidth double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
score int
getter/setter pair

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object. After this is called, the object is not in a usable state and should be discarded (calls to addListener will throw after the object is disposed).
override
jump() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
restart() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited