Obstacle class

Constructors

Obstacle({required Offset position, required Size size, required String assetPath})

Properties

assetPath String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
passed bool
getter/setter pair
position Offset
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size Size
getter/setter pair

Methods

getRect() Rect
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited