AudioService class

Constructors

AudioService()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
playBackgroundMusic({int track = 1}) Future<void>
Plays looping background music (automatically preloads on first call).
playGameOver() Future<void>
Plays the “game over” SFX (auto‐preloads first).
playJump() Future<void>
Plays the “jump” SFX (auto‐preloads first).
playPoint() Future<void>
Plays the “point” (tick) SFX (auto‐preloads first).
stopBackgroundMusic() Future<void>
Stops background music.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited